@@ -32,6 +32,7 @@ import aws_cdk.aws_autoscaling._jsii
 import aws_cdk.aws_autoscalingplans._jsii
 import aws_cdk.aws_backup._jsii
 import aws_cdk.aws_batch._jsii
+import aws_cdk.aws_billingconductor._jsii
 import aws_cdk.aws_budgets._jsii
 import aws_cdk.aws_cassandra._jsii
 import aws_cdk.aws_ce._jsii
@@ -108,6 +109,7 @@ import aws_cdk.aws_iotevents._jsii
 import aws_cdk.aws_iotfleethub._jsii
 import aws_cdk.aws_iotsitewise._jsii
 import aws_cdk.aws_iotthingsgraph._jsii
+import aws_cdk.aws_iottwinmaker._jsii
 import aws_cdk.aws_iotwireless._jsii
 import aws_cdk.aws_ivs._jsii
 import aws_cdk.aws_kafkaconnect._jsii
@@ -135,6 +137,7 @@ import aws_cdk.aws_mediaconvert._jsii
 import aws_cdk.aws_medialive._jsii
 import aws_cdk.aws_mediapackage._jsii
 import aws_cdk.aws_mediastore._jsii
+import aws_cdk.aws_mediatailor._jsii
 import aws_cdk.aws_memorydb._jsii
 import aws_cdk.aws_msk._jsii
 import aws_cdk.aws_mwaa._jsii
@@ -198,9 +201,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.149.0",
+    "1.156.1",
     __name__[0:-6],
-    "cloudformation-include@1.149.0.jsii.tgz",
+    "cloudformation-include@1.156.1.jsii.tgz",
 )
 
 __all__ = [
